==> zio-aws-globalaccelerator_2.13-5.17.104.13-sources.jar: zio/aws/globalaccelerator/model/UpdateCustomRoutingAcceleratorRequest.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.globalaccelerator.model.primitives.{
  GenericBoolean,
  GenericString
}
import scala.jdk.CollectionConverters._
final case class UpdateCustomRoutingAcceleratorRequest(
    acceleratorArn: GenericString,
    name: Option[GenericString] = None,
    ipAddressType: Option[zio.aws.globalaccelerator.model.IpAddressType] = None,
    enabled: Option[GenericBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest = {
    import UpdateCustomRoutingAcceleratorRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
      .builder()
      .acceleratorArn(GenericString.unwrap(acceleratorArn): java.lang.String)
      .optionallyWith(
        name.map(value => GenericString.unwrap(value): java.lang.String)
      )(_.name)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .optionallyWith(
        enabled.map(value => GenericBoolean.unwrap(value): java.lang.Boolean)
      )(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly =
    zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
      .wrap(buildAwsValue())
}
object UpdateCustomRoutingAcceleratorRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest =
      zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest(
        acceleratorArn,
        name.map(value => value),
        ipAddressType.map(value => value),
        enabled.map(value => value)
      )
    def acceleratorArn: GenericString
    def name: Option[GenericString]
    def ipAddressType: Option[zio.aws.globalaccelerator.model.IpAddressType]
    def enabled: Option[GenericBoolean]
    def getAcceleratorArn: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(acceleratorArn)
    def getName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("name", name)
    def getIpAddressType
        : ZIO[Any, AwsError, zio.aws.globalaccelerator.model.IpAddressType] =
      AwsError.unwrapOptionField("ipAddressType", ipAddressType)
    def getEnabled: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ) extends zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly {
    override val acceleratorArn: GenericString =
      zio.aws.globalaccelerator.model.primitives
        .GenericString(impl.acceleratorArn())
    override val name: Option[GenericString] = scala
      .Option(impl.name())
      .map(value =>
        zio.aws.globalaccelerator.model.primitives.GenericString(value)
      )
    override val ipAddressType
        : Option[zio.aws.globalaccelerator.model.IpAddressType] = scala
      .Option(impl.ipAddressType())
      .map(value => zio.aws.globalaccelerator.model.IpAddressType.wrap(value))
    override val enabled: Option[GenericBoolean] = scala
      .Option(impl.enabled())
      .map(value =>
        zio.aws.globalaccelerator.model.primitives.GenericBoolean(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ): zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-globalaccelerator_2.13-5.17.157.2-sources.jar: zio/aws/globalaccelerator/model/UpdateCustomRoutingAcceleratorRequest.scala <==
package zio.aws.globalaccelerator.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.globalaccelerator.model.primitives.{
  GenericBoolean,
  GenericString
}
import scala.jdk.CollectionConverters._
final case class UpdateCustomRoutingAcceleratorRequest(
    acceleratorArn: GenericString,
    name: Option[GenericString] = None,
    ipAddressType: Option[zio.aws.globalaccelerator.model.IpAddressType] = None,
    enabled: Option[GenericBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest = {
    import UpdateCustomRoutingAcceleratorRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
      .builder()
      .acceleratorArn(acceleratorArn: java.lang.String)
      .optionallyWith(name.map(value => value: java.lang.String))(_.name)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .optionallyWith(enabled.map(value => value: java.lang.Boolean))(_.enabled)
      .build()
  }
  def asReadOnly
      : zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly =
    zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
      .wrap(buildAwsValue())
}
object UpdateCustomRoutingAcceleratorRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest =
      zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest(
        acceleratorArn,
        name.map(value => value),
        ipAddressType.map(value => value),
        enabled.map(value => value)
      )
    def acceleratorArn: GenericString
    def name: Option[GenericString]
    def ipAddressType: Option[zio.aws.globalaccelerator.model.IpAddressType]
    def enabled: Option[GenericBoolean]
    def getAcceleratorArn: ZIO[Any, Nothing, GenericString] =
      ZIO.succeed(acceleratorArn)
    def getName: ZIO[Any, AwsError, GenericString] =
      AwsError.unwrapOptionField("name", name)
    def getIpAddressType
        : ZIO[Any, AwsError, zio.aws.globalaccelerator.model.IpAddressType] =
      AwsError.unwrapOptionField("ipAddressType", ipAddressType)
    def getEnabled: ZIO[Any, AwsError, GenericBoolean] =
      AwsError.unwrapOptionField("enabled", enabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ) extends zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly {
    override val acceleratorArn: GenericString =
      impl.acceleratorArn(): GenericString
    override val name: Option[GenericString] =
      scala.Option(impl.name()).map(value => value: GenericString)
    override val ipAddressType
        : Option[zio.aws.globalaccelerator.model.IpAddressType] = scala
      .Option(impl.ipAddressType())
      .map(value => zio.aws.globalaccelerator.model.IpAddressType.wrap(value))
    override val enabled: Option[GenericBoolean] =
      scala.Option(impl.enabled()).map(value => value: GenericBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest
  ): zio.aws.globalaccelerator.model.UpdateCustomRoutingAcceleratorRequest.ReadOnly =
    new Wrapper(impl)
}
